# Worker Automate Hub

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/worker-automate-hub)
[![PyPI version](https://badge.fury.io/py/worker-automate-hub.svg)](https://badge.fury.io/py/worker-automate-hub)

## Installation

Worker Automate Hub is available on PyPI. You can install it through `pip`:

```bash
    pipx install worker-automate-hub
```

## Requirements and Tested Platforms

- Python:
  - 3.12 or higher
- Windows (32bit/64bit/ARM64):

  - Worker Automate Hub should work on Windows 7 or newer, but we only officially support Windows 8+.

# TODO

RUN
LINT
